==> pyhomebroker-0.1.tar.gz: pyhomebroker-0.1/pyhomebroker/_brokers.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Home Broker API - Market data downloader
# https://github.com/crapher/pyhomebroker.git
#
# Copyright 2020 Diego Degese
#
# Licensed under the Apache License, Version 2.0 (the 'License');
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

brokers = [
    {
    'broker_id': 12,
    'name': 'Buenos Aires Valores S.A.',
    'page': 'https://operarhb.bavsa.com'
    },
    {
    'broker_id': 20,
    'name': 'Proficio Investment S.A.',
    'page': 'https://newsystem.proficioinvestment.com.ar'
    },
    {
    'broker_id': 81,
    'name': 'Tomar Inversiones S.A',
    'page': 'https://clientes2.tminversiones.com.ar'
    },
    {
    'broker_id': 127,
    'name': 'Maestro y Huerres S.A',
    'page': 'https://operar.maestroyhuerres.com'
    },
    {
    'broker_id': 164,
    'name': 'Prosecurities S.A.',
    'page': 'https://operar.psec.com.ar'
    },
    {
    'broker_id': 203,
    'name': 'Invertir en Bolsa S.A.',
    'page': 'https://clientesv2.invertirenbolsa.com.ar'
    },
    {
    'broker_id': 209,
    'name': 'Futuro Bursátil S.A.',
    'page': 'https://homebroker.futurobursatil.com.ar'
    }
]

==> pyhomebroker-0.1.1.tar.gz: pyhomebroker-0.1.1/pyhomebroker/_brokers.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Home Broker API - Market data downloader
# https://github.com/crapher/pyhomebroker.git
#
# Copyright 2020 Diego Degese
#
# Licensed under the Apache License, Version 2.0 (the 'License');
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

brokers = [
    {
    'broker_id': 12,
    'name': 'Buenos Aires Valores S.A.',
    'page': 'https://operarhb.bavsa.com'
    },
    {
    'broker_id': 20,
    'name': 'Proficio Investment S.A.',
    'page': 'https://newsystem.proficioinvestment.com.ar'
    },
    {
    'broker_id': 81,
    'name': 'Tomar Inversiones S.A',
    'page': 'https://clientes2.tminversiones.com.ar'
    },
    {
    'broker_id': 88,
    'name': 'Bell Investments S.A.',
    'page': 'https://operar.bellbursatil.com'
    },
    {
    'broker_id': 127,
    'name': 'Maestro y Huerres S.A',
    'page': 'https://operar.maestroyhuerres.com'
    },
    {
    'broker_id': 153,
    'name': 'Bolsa de Comercio del Chaco',
    'page': 'https://clientes.bcch.org.ar'
    },
    {
    'broker_id': 164,
    'name': 'Prosecurities S.A.',
    'page': 'https://operar.psec.com.ar'
    },
    {
    'broker_id': 203,
    'name': 'Invertir en Bolsa S.A.',
    'page': 'https://clientesv2.invertirenbolsa.com.ar'
    },
    {
    'broker_id': 209,
    'name': 'Futuro Bursátil S.A.',
    'page': 'https://homebroker.futurobursatil.com.ar'
    }
]
